@@ -720,6 +720,18 @@ class QueryLMS():
 #         return now_playing_info
     
     def get_now_playing(self):
+        '''query associated player for now playing information including:
+        * album
+        * artist
+        * artwork_url
+        * duration
+        * genre
+        * coverid
+        * id
+        * title
+        
+        Returns:
+            dict'''
         status = self.query(self.player_id, 'status', '-')
         playlist = status.get('playlist_loop', [])
         
